function [scores, levels, theta, Z_pos,T,PCidx,maxlev,all_nodes]= Score_JTree(X, K, TrainIdx,TestIdx)

% function [scores, levels] = Score_JTree(X, K, TrainIdx, TestIdx)
%
% Function: For each level of the tree, compute the score of the best K-basis,
% i.e. the total energy of the K basis vectors with maximum variance
%
% Input: 
%   X           -- data matrix (each row is an observation)
%   K           -- number of vectors in final representation
%   TrainIdx    -- indices for train data (for building the tree)
%   TestIdx     -- indices for test data (for computing a score)
%
% Function calls: Build_JTree (calls newJacobi), JTree_Basis
% The returned variables are computed on a maximum level tree
% Remark: Compare this function with Run_JTree
%
% Ann B. Lee, April 2007. Last updated, ABL: 4/15/08

%----------------------------------------------------
% BUILD TREE USING TRAIN DATA (each row is a sample)
%----------------------------------------------------
Xtrain=X(TrainIdx,:); %size(Xtrain),
[N,dim]=size(Xtrain);

disp('Computing correlations...');
Xtrain = Xtrain - ones(N,1)*mean(Xtrain,1);   % center the data
tmp_norm=sqrt(sum(Xtrain.*Xtrain,1));  Xnorm=Xtrain./(ones(N,1)*tmp_norm);  % data matrix with normalized columns
cc=Xnorm'*Xnorm; clear Xnorm tmp_norm
C=Xtrain'*Xtrain/N; clear Xtrain;

% RUN TREELET ALGORITHM
disp('Computing multiscale tree decomposition...');
maxlev=dim-1; % <=dim-1
[Z_pos, T, PCidx, all_nodes, theta, PC_ratio, Z,all_d] = Build_JTree(C,cc,maxlev); % modified 4/4/07

%----------------------------------------------
% COMPUTE SCORE ON TEST DATA
%----------------------------------------------
Xtest=X(TestIdx,:); %size(Xtest),
disp('Computing and scoring orthogonal bases...');
[scores, levels] =  JTree_Scores(Xtest, K,Z_pos,T,PCidx,maxlev,all_nodes);
return,
